## packages
require(sp)
require(raster)
require(rgdal)

## set file location of the extracted folder "/Data code repository" on your PC:
setwd = "/Data code repository"


## Load the data:

## read 300m resolution raster of habitat suitability from C. rosei (target species) species distribution model (SDM) output:
ros300mn=raster("C.ros_300_Mn0.asc")
proj4string(ros300mn)="+proj=utm +zone=34 +south +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0" 

## read spreadsheet with midpoints of all 96 (300x300m) grid-cells searched: 
"C.ros_searched_96.csv"
df.S = read.csv("C.ros_searched_96.csv")


#################################################################################################
## Constant conversion factors: upper and lower bounds
c3 = (3/length(na.omit(values(ros300mn))))/(mean(na.omit(values(ros300mn))))
c7 = (7/length(na.omit(values(ros300mn))))/(mean(na.omit(values(ros300mn))))


##############################################################################
## calculate E(Psi) upper and lower bound rasters for unsearched
E.Psi.3 = ros300mn*c3
E.Psi.7 = ros300mn*c7


##########################################################################################
## Calculate p of no more unknown populations remaining Before search:

 #excluding only the two cells SM and GD
P.N.A_before_3 = (prod(na.omit(values(1-E.Psi.3))))/(1-(0.450303404*c3))/
  (1-(0.561645434*c3))

P.N.A_before_7 = (prod(na.omit(values(1-E.Psi.7))))/(1-(0.450303404*c7))/
  (1-(0.561645434*c7))


###########################################################################################
## Calculate total P(no more unknowns) after search - upper and lower bounds

P.N.A_after_3 =  (prod(na.omit(values(1-E.Psi.3 ))))/
  (prod(na.omit(extract(1-E.Psi.3, cbind(df.S[,2], df.S[,3])))))

P.N.A_after_7 = (prod(na.omit(values(1-E.Psi.7 ))))/
  (prod(na.omit(extract(1-E.Psi.7, cbind(df.S[,2], df.S[,3])))))


## Final probability values
P.N.A_after_3
P.N.A_after_7

# factor improved after search
P.N.A_after_3/P.N.A_before_3
P.N.A_after_7/P.N.A_before_7



###########################################################################################
## Table Mountain:
###########################################################################################

####################################################################################
## read shapefile of Table Mountain area, reproject to UTM, and extract data from overlap:
TableMt <- readOGR(dsn = "Layers", layer = "Table")
TableMt = spTransform(TableMt, CRS("+proj=utm +zone=34 +south +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))

# vector of values for Table Mountain cells (upper and lower bounds):
df.Tbl_3 = na.omit(extract(E.Psi.3, TableMt))
df.Tbl_3 = df.Tbl_3[[1]]
df.Tbl_7 = na.omit(extract(E.Psi.7, TableMt))
df.Tbl_7 = df.Tbl_7[[1]]

####################################################################################
## Probability of no pops occurring on Table Mt, before search:

P.N.A_Tbl_before_3 = prod(1-df.Tbl_3)
P.N.A_Tbl_before_7 = prod(1-df.Tbl_7)

####################################################################################
## Probability of no pops occurring on Table Mt, after search:

## read data of searched sites on Table Mountain, and transform to UTM coordinates:
# insert location of "C.ros_searched_Table.csv" file
df.Tbl = read.csv("C.ros_searched_Table.csv")
df.Tbl =SpatialPointsDataFrame(coords=cbind(df.Tbl$lon, df.Tbl$lat), 
                             data=df.Tbl, proj4string=CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"))
df.Tbl =spTransform(df.Tbl, 
                  CRSobj=CRS("+proj=utm +zone=34 +south +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))
df.Tbl = as.data.frame(cbind(coordinates(df.Tbl)[,1], coordinates(df.Tbl)[,2]))
colnames(df.Tbl) = c("x", "y")

##########################################################################################
## P of no more unknown after search
P.N.A_Tbl_after_3 = P.N.A_Tbl_before_3/(prod(extract(1-E.Psi.3, df.Tbl)))
P.N.A_Tbl_after_7 = P.N.A_Tbl_before_7/(prod(extract(1-E.Psi.7, df.Tbl)))


## summary values for Table Mountain:
P.N.A_Tbl_after_3
P.N.A_Tbl_after_7

# factor improved
P.N.A_Tbl_after_3/P.N.A_Tbl_before_3
P.N.A_Tbl_after_7/P.N.A_Tbl_before_7

